"""
Discord API Wrapper
~~~~~~~~~~~~~~~~~~~

A basic wrapper for the Discord API.

:copyright: (c) 2015-present Rapptz
:license: MIT, see LICENSE for more details.

"""

__title__ = 'shopee-wrapper'
__author__ = 'munawariz'
__license__ = 'MIT'
__copyright__ = 'Copyright 2022-present munawariz'
__version__ = '0.3'

from .base import *
from .product import *
from .review import *
from .shop import *